difflicious.differ.LazyDiffer
See theLazyDiffer companion object
final class LazyDiffer[T](mkDiffer: => Differ[T]) extends Differ[T]
A wrapper over another Differ that lazily initializes it when needed. Used to break self-referencing cycles such as recursive data structures
Attributes
- Companion
- object
- Graph
-
- Supertypes
Members list
Type members
Types
Value members
Concrete methods
Attributes
- Definition Classes
Inherited methods
Attributes
- Inherited from:
- ConfigureMethods
final def configureRaw(path: ConfigurePath, operation: ConfigureOp): Either[ConfigureError, Differ[T]]
Attempt to change the configuration of this Differ. If successful, a new differ with the updated configuration will be returned.
Attempt to change the configuration of this Differ. If successful, a new differ with the updated configuration will be returned.
The configuration change can fail due to
- bad "path" that does not match the internal structure of the Differ
- The path resolved correctly, but the configuration update operation cannot be applied for that part of the Differ (e.g. wrong type or wrong operation)
Value parameters
- operation
-
The configuration change operation you want to perform on the target sub-Differ
- path
-
The path to traverse to the sub-Differ
Attributes
- Inherited from:
- Differ
Attributes
- Inherited from:
- ConfigureMethods
Attributes
- Inherited from:
- ConfigureMethods
Inherited fields
Attributes
- Inherited from:
- ConfigureMethods
In this article